<?php
// $Id: taxonomy_context.admin.inc,v 1.1.2.1 2009/10/03 18:47:11 nancyw Exp $

/**
 * @file
 * Create a block as a hierarchical menu tree for each vocabulary. 
 */

function taxonomy_context_admin_settings() {
  // We need the CSS here.
  drupal_add_css(drupal_get_path('module', 'taxonomy_context') . '/taxonomy_context.css');

  $form = array();
  $endis = array(t('Disabled'), t('Enabled'));

  $form['general_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General Settings'),
    '#collapsible' => TRUE,
    );

  $form['general_settings']['taxonomy_context_use_style'] = array(
    '#type' => 'radios',
    '#title' => t('Use style for term and subterm display'),
    '#default_value' => variable_get('taxonomy_context_use_style', 0),
    '#options' => $endis,
    '#description' => t('Include style declaration to clean up display of taxonomy info. Disable this option if you wish to do this instead through editing theme .css files.'),
    );

  $form['general_settings']['taxonomy_context_show_term'] = array(
    '#type' => 'radios',
    '#title' => t('Show term info'),
    '#default_value' => variable_get('taxonomy_context_show_term', 1),
    '#options' => $endis,
    '#description' => t('Show additional information about current term (from description).'),
    );

  $form['general_settings']['taxonomy_context_show_subterms'] = array(
    '#type' => 'radios',
    '#title' => t('Show subterm info'),
    '#default_value' => variable_get('taxonomy_context_show_subterms', 1),
    '#options' => $endis,
    '#description' => t('Show listings of subterms (sub-categories) for current term.'),
    );

  $form['general_settings']['taxonomy_context_subterm_indent'] = array(
    '#type' => 'textfield',
    '#title' => t('Subterm indent character'),
    '#default_value' => variable_get('taxonomy_context_subterm_indent', '&mdash;'),
    '#size' => 32,
    '#description' => t('Subterms will be indented to show hierarchy; this is what is used to show the indentation. It will be repeated for each level of depth.'),
    );

  $form['general_settings']['taxonomy_context_max_depth'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum term depth for overview'),
    '#default_value' => variable_get('taxonomy_context_max_depth', 1),
    '#size' => 8,
    '#description' => t('This is how deep in the hierarchy to show terms on the overview ("menu") page. A value of 1 show only the highest level.'),
    );
  $num_titles = variable_get('taxonomy_context_show_titles', 0);
  $order = variable_get('taxonomy_context_show_order', 'n.title');

  $form['general_settings']['titles'] = array(
    '#type' => 'fieldset',
    '#title' => t('Node title display'),
    '#collapsible' => TRUE,
    );

  $form['general_settings']['titles']['taxonomy_context_show_titles'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum titles to show for each term'),
    '#default_value' => variable_get('taxonomy_context_show_titles', 0),
    '#size' => 8,
    '#description' => t('This is how many node titles to show for each term on the overview ("menu") page. A value of 0 means don\'t show any.'),
    );

  $form['general_settings']['titles']['taxonomy_context_show_order'] = array(
    '#type' => 'radios',
    '#title' => t('Title order'),
    '#default_value' => variable_get('taxonomy_context_show_order', 'n.title'),
    '#options' => array(
      'n.title' => t('by title (ascending)'),
      'n.sticky DESC, n.created DESC' => t('by standard Drupal order (sticky, most recent)'),
      ),
    '#description' => t('In what order do you wish to show the titles? This may also affect which titles are shown if there are more than the limit above.'),
    );

  $form['general_settings']['taxonomy_context_node_block'] = array(
    '#type' => 'radios',
    '#title' => t('Show nodes in block'),
    '#default_value' => variable_get('taxonomy_context_node_block', TAXONOMY_CONTEXT_NODE_BLOCK_NONE),
    '#options' => array(t('None'), t('Sticky'), t('Promoted'), t('All')),
    '#description' => t('What nodes do you wish to display in taxonomy blocks?'),
    );

  $form['general_settings']['taxonomy_context_block_display'] = array(
    '#type' => 'radios',
    '#title' => t('Show block items'),
    '#default_value' => variable_get('taxonomy_context_block_display', TAXONOMY_CONTEXT_BLOCK_DISPLAY_COLLAPSED),
    '#options' => array(t('Collapsed'), t('Expanded')),
    '#description' => t('Do you want items on the menu expanded or collapsed by default?'),
    );

  $form['general_settings']['taxonomy_context_count_nodes'] = array(
    '#type' => 'radios',
    '#title' => t('Show node count on overview page'),
    '#default_value' => variable_get('taxonomy_context_count_nodes', 0),
    '#options' => $endis,
    '#description' => t('Show the number of nodes tagged with each term. For example: term-name (nnn)'),
    );

  $form['general_settings']['taxonomy_context_block_count_nodes'] = array(
    '#type' => 'radios',
    '#title' => t('Show count nodes in block items'),
    '#default_value' => variable_get('taxonomy_context_block_count_nodes', TAXONOMY_CONTEXT_BLOCK_COUNT_NODES_FALSE),
    '#options' => $endis,
    '#description' => t('Show count nodes in block after items. Example: term (nnn)'),
    );

  return system_settings_form($form);
}
